@@ -1,9 +1,9 @@
-# Honeybee: A Plugin for Environmental Analysis (GPL)
-# This file is part of Honeybee.
+# Dragonfly: A Plugin for Environmental Analysis (GPL)
+# This file is part of Dragonfly.
 #
 # Copyright (c) 2023, Ladybug Tools.
 # You should have received a copy of the GNU Affero General Public License
-# along with Honeybee; If not, see <http://www.gnu.org/licenses/>.
+# along with Dragonfly; If not, see <http://www.gnu.org/licenses/>.
 # 
 # @license AGPL-3.0-or-later <https://spdx.org/licenses/AGPL-3.0-or-later>
 
@@ -42,7 +42,7 @@ of occupancy is so low that infiltration is enough to meet fresh air demand.
 
 ghenv.Component.Name = "DF HeatCool HVAC"
 ghenv.Component.NickName = 'DFHeatCoolHVAC'
-ghenv.Component.Message = '1.6.0'
+ghenv.Component.Message = '1.6.2'
 ghenv.Component.Category = 'Dragonfly'
 ghenv.Component.SubCategory = '3 :: Energy'
 ghenv.Component.AdditionalHelpFromDocStrings = '3'
@@ -140,12 +140,13 @@ if all_required_inputs(ghenv.Component):
     for obj in df_objs:
         if isinstance(obj, (Building, Story)):
             obj.properties.energy.set_all_room_2d_hvac(hvac)
-        elif isinstance(obj, Room2D) and obj.properties.energy.is_conditioned:
-            obj.properties.energy.hvac = hvac
+        elif isinstance(obj, Room2D):
+            if obj.properties.energy.is_conditioned:
+                obj.properties.energy.hvac = hvac
         elif isinstance(obj, Model):
             for bldg in obj.buildings:
                 bldg.properties.energy.set_all_room_2d_hvac(hvac)
         else:
             raise ValueError(
                 'Expected Dragonfly Room2D, Story, Building, or Model. '
-                'Got {}.'.format(type(hb_obj)))
+                'Got {}.'.format(type(obj)))
